<?php
/**
 * Gallery section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage Mega Blog Pro
 * @since Mega Blog Pro 1.0.0
 */
if ( ! function_exists( 'mega_blog_pro_add_gallery_section' ) ) :
    /**
    * Add gallery section
    *
    *@since Mega Blog Pro 1.0.0
    */
    function mega_blog_pro_add_gallery_section() {
    	$options = mega_blog_pro_get_theme_options();
        // Check if gallery is enabled on frontpage
        $gallery_enable = apply_filters( 'mega_blog_pro_section_status', true, 'gallery_section_enable' );

        if ( true !== $gallery_enable ) {
            return false;
        }
        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'mega_blog_pro_filter_gallery_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render gallery section now.
        mega_blog_pro_render_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_blog_pro_get_gallery_section_details' ) ) :
    /**
    * gallery section details.
    *
    * @since Mega Blog Pro 1.0.0
    * @param array $input gallery section details.
    */
    function mega_blog_pro_get_gallery_section_details( $input ) {
        $options = mega_blog_pro_get_theme_options();

        // Content type.
        $gallery_content_type  = $options['gallery_content_type'];
        $gallery_count = ! empty( $options['gallery_count'] ) ? $options['gallery_count'] : 3;
        
        $content = array();
        switch ( $gallery_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_page_' . $i] ) )
                        $page_ids[] = $options['gallery_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_post_' . $i] ) )
                        $post_ids[] = $options['gallery_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['gallery_content_category'] ) ? $options['gallery_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $gallery_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = get_the_excerpt();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'mega-blog-pro-medium' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                    $page_post['author']    = mega_blog_pro_author();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// gallery section content details.
add_filter( 'mega_blog_pro_filter_gallery_section_details', 'mega_blog_pro_get_gallery_section_details' );


if ( ! function_exists( 'mega_blog_pro_render_gallery_section' ) ) :
  /**
   * Start gallery section
   *
   * @return string gallery content
   * @since Mega Blog Pro 1.0.0
   *
   */
   function mega_blog_pro_render_gallery_section( $content_details = array() ) {
        $options = mega_blog_pro_get_theme_options();
        $gallery_content_type  = $options['gallery_content_type'];
        $gallery_alignment = ! empty( $options['gallery_alignment'] ) ? $options['gallery_alignment'] : 'left-align';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="gallery-posts" class="page-section relative <?php echo esc_attr( $gallery_alignment ); ?>">
            <div class="wrapper">
                <?php if ( ! empty( $options['gallery_title'] ) ) : ?>
                    <div class="section-header align-center add-separator">
                        <h2 class="section-title"><?php echo esc_html( $options['gallery_title'] ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="section-content gallery-post-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1200, "dots": false, "arrows":true, "autoplay": true, "fade": true, "draggable": true }'>
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="hentry">
                            <div class="post-wrapper">
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <?php if ( 'page' !== $gallery_content_type ) :
                                            mega_blog_pro_posted_on( $content['id'] );
                                        endif; ?>

                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <?php echo esc_html( $content['excerpt'] ); ?>
                                    </div><!-- .entry-content -->

                                    <?php if ( 'page' !== $gallery_content_type ) : ?>
                                        <div class="entry-meta">
                                            <?php echo wp_kses_post( mega_blog_pro_article_footer_meta( $content['id'], $content['author'] ) ); ?>
                                        </div><!-- .entry-meta -->
                                    <?php endif; ?>
                                </div><!-- .entry-container -->
                            </div><!-- .post-wrapper -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #gallery-posts -->
    <?php }
endif;